"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def flush(hub, ctx, rest_api_id: str, stage_name: str) -> None:
    r"""
    **Autogenerated function**

    Flushes a stage's cache.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        stage_name(str): [Required] The name of the stage to flush its cache.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.stage.cache.flush(
                ctx, rest_api_id=value, stage_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.stage.cache.flush rest_api_id=value, stage_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="flush_stage_cache",
        op_kwargs={"restApiId": rest_api_id, "stageName": stage_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str,
    source_type: str = None,
    event_categories: List = None,
    source_ids: List = None,
    enabled: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an RDS event notification subscription. This action requires a topic Amazon Resource Name (ARN) created by either the RDS console, the SNS console, or the SNS API. To obtain an ARN with SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the SNS console. You can specify the type of source (SourceType) that you want to be notified of and provide a list of RDS sources (SourceIds) that triggers the events. You can also provide a list of event categories (EventCategories) for events that you want to be notified of. For example, you can specify SourceType = db-instance, SourceIds = mydbinstance1, mydbinstance2 and EventCategories = Availability, Backup. If you specify both the SourceType and SourceIds, such as SourceType = db-instance and SourceIdentifier = myDBInstance1, you are notified of all the db-instance events for the specified source. If you specify a SourceType but do not specify a SourceIdentifier, you receive notice of the events for that source type for all your RDS sources. If you don't specify either the SourceType or the SourceIdentifier, you are notified of events generated from all RDS sources belonging to your customer account.  RDS event notification is only available for unencrypted SNS topics. If you specify an encrypted SNS topic, event notifications aren't sent for the topic.

    Args:
        subscription_name(str): The name of the subscription. Constraints: The name must be less than 255 characters.
        sns_topic_arn(str): The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it.
        source_type(str, optional): The type of source that is generating the events. For example, if you want to be notified of events generated by a DB instance, you set this parameter to db-instance. If this value isn't specified, all events are returned. Valid values: db-instance | db-cluster | db-parameter-group | db-security-group | db-snapshot | db-cluster-snapshot . Defaults to None.
        event_categories(List, optional):  A list of event categories for a particular source type (SourceType) that you want to subscribe to. You can see a list of the categories for a given source type in Events in the Amazon RDS User Guide or by using the DescribeEventCategories operation. . Defaults to None.
        source_ids(List, optional): The list of identifiers of the event sources for which events are returned. If not specified, then all sources are included in the response. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens. It can't end with a hyphen or contain two consecutive hyphens. Constraints:   If SourceIds are supplied, SourceType must also be provided.   If the source type is a DB instance, a DBInstanceIdentifier value must be supplied.   If the source type is a DB cluster, a DBClusterIdentifier value must be supplied.   If the source type is a DB parameter group, a DBParameterGroupName value must be supplied.   If the source type is a DB security group, a DBSecurityGroupName value must be supplied.   If the source type is a DB snapshot, a DBSnapshotIdentifier value must be supplied.   If the source type is a DB cluster snapshot, a DBClusterSnapshotIdentifier value must be supplied.  . Defaults to None.
        enabled(bool, optional):  A value that indicates whether to activate the subscription. If the event notification subscription isn't activated, the subscription is created but not active. . Defaults to None.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.event.subscription.create(
                ctx, subscription_name=value, sns_topic_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.event.subscription.create subscription_name=value, sns_topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "EventCategories": event_categories,
            "SourceIds": source_ids,
            "Enabled": enabled,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, subscription_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an RDS event notification subscription.

    Args:
        subscription_name(str): The name of the RDS event notification subscription you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.event.subscription.delete(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.event.subscription.delete subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_event_subscription",
        op_kwargs={"SubscriptionName": subscription_name},
    )


async def describe_all(
    hub,
    ctx,
    subscription_name: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the subscription descriptions for a customer account. The description for a subscription includes SubscriptionName, SNSTopicARN, CustomerID, SourceType, SourceID, CreationTime, and Status. If you specify a SubscriptionName, lists the description for that subscription.

    Args:
        subscription_name(str, optional): The name of the RDS event notification subscription you want to describe. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords . . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.event.subscription.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.event.subscription.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_event_subscriptions",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str = None,
    source_type: str = None,
    event_categories: List = None,
    enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing RDS event notification subscription. You can't modify the source identifiers using this call. To change source identifiers for a subscription, use the AddSourceIdentifierToSubscription and RemoveSourceIdentifierFromSubscription calls. You can see a list of the event categories for a given source type (SourceType) in Events in the Amazon RDS User Guide or by using the DescribeEventCategories operation.

    Args:
        subscription_name(str): The name of the RDS event notification subscription.
        sns_topic_arn(str, optional): The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it. Defaults to None.
        source_type(str, optional): The type of source that is generating the events. For example, if you want to be notified of events generated by a DB instance, you would set this parameter to db-instance. If this value isn't specified, all events are returned. Valid values: db-instance | db-cluster | db-parameter-group | db-security-group | db-snapshot | db-cluster-snapshot . Defaults to None.
        event_categories(List, optional):  A list of event categories for a source type (SourceType) that you want to subscribe to. You can see a list of the categories for a given source type in Events in the Amazon RDS User Guide or by using the DescribeEventCategories operation. . Defaults to None.
        enabled(bool, optional):  A value that indicates whether to activate the subscription. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.event.subscription.modify(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.event.subscription.modify subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "EventCategories": event_categories,
            "Enabled": enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, instance_id: str, routing_profile_id: str, queue_configs: List
) -> None:
    r"""
    **Autogenerated function**

    Associates a set of queues with a routing profile.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        routing_profile_id(str): The identifier of the routing profile.
        queue_configs(List): The queues to associate with this routing profile.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.queue.associate(
                ctx, instance_id=value, routing_profile_id=value, queue_configs=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.queue.associate instance_id=value, routing_profile_id=value, queue_configs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="associate_routing_profile_queues",
        op_kwargs={
            "InstanceId": instance_id,
            "RoutingProfileId": routing_profile_id,
            "QueueConfigs": queue_configs,
        },
    )


async def disassociate(
    hub, ctx, instance_id: str, routing_profile_id: str, queue_references: List
) -> None:
    r"""
    **Autogenerated function**

    Disassociates a set of queues from a routing profile.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        routing_profile_id(str): The identifier of the routing profile.
        queue_references(List): The queues to disassociate from this routing profile.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.queue.disassociate(
                ctx, instance_id=value, routing_profile_id=value, queue_references=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.queue.disassociate instance_id=value, routing_profile_id=value, queue_references=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="disassociate_routing_profile_queues",
        op_kwargs={
            "InstanceId": instance_id,
            "RoutingProfileId": routing_profile_id,
            "QueueReferences": queue_references,
        },
    )


async def list_all(
    hub,
    ctx,
    instance_id: str,
    routing_profile_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the queues associated with a routing profile.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        routing_profile_id(str): The identifier of the routing profile.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.queue.list_all(
                ctx, instance_id=value, routing_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.queue.list_all instance_id=value, routing_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_routing_profile_queues",
        op_kwargs={
            "InstanceId": instance_id,
            "RoutingProfileId": routing_profile_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update_multiple(
    hub, ctx, instance_id: str, routing_profile_id: str, queue_configs: List
) -> None:
    r"""
    **Autogenerated function**

    Updates the properties associated with a set of queues for a routing profile.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        routing_profile_id(str): The identifier of the routing profile.
        queue_configs(List): The queues to be updated for this routing profile. Queues must first be associated to the routing profile. You can do this using AssociateRoutingProfileQueues.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.queue.update_multiple(
                ctx, instance_id=value, routing_profile_id=value, queue_configs=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.queue.update_multiple instance_id=value, routing_profile_id=value, queue_configs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_routing_profile_queues",
        op_kwargs={
            "InstanceId": instance_id,
            "RoutingProfileId": routing_profile_id,
            "QueueConfigs": queue_configs,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(hub, ctx, device_key: str, user_pool_id: str, username: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the device, as an administrator. Calling this action requires developer credentials.

    Args:
        device_key(str): The device key.
        user_pool_id(str): The user pool ID.
        username(str): The user name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.get.device.admin(
                ctx, device_key=value, user_pool_id=value, username=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.get.device.admin device_key=value, user_pool_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_get_device",
        op_kwargs={
            "DeviceKey": device_key,
            "UserPoolId": user_pool_id,
            "Username": username,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    transit_gateway_attachment_id: str = None,
    subnet_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified subnets and transit gateway attachments with the specified transit gateway multicast domain. The transit gateway attachment must be in the available state before you can add a resource. Use DescribeTransitGatewayAttachments to see the state of the attachment.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        transit_gateway_attachment_id(str, optional): The ID of the transit gateway attachment to associate with the transit gateway multicast domain. Defaults to None.
        subnet_ids(List, optional): The IDs of the subnets to associate with the transit gateway multicast domain. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.init.associate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.init.associate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_transit_gateway_multicast_domain",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "SubnetIds": subnet_ids,
            "DryRun": dry_run,
        },
    )


async def create(
    hub,
    ctx,
    transit_gateway_id: str,
    options: Dict = None,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a multicast domain using the specified transit gateway. The transit gateway must be in the available state before you create a domain. Use DescribeTransitGateways to see the state of transit gateway.

    Args:
        transit_gateway_id(str): The ID of the transit gateway.
        options(Dict, optional): The options for the transit gateway multicast domain. Defaults to None.
        tag_specifications(List, optional): The tags for the transit gateway multicast domain. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.init.create(
                ctx, transit_gateway_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.init.create transit_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway_multicast_domain",
        op_kwargs={
            "TransitGatewayId": transit_gateway_id,
            "Options": options,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, transit_gateway_multicast_domain_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified transit gateway multicast domain.

    Args:
        transit_gateway_multicast_domain_id(str): The ID of the transit gateway multicast domain.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.init.delete(
                ctx, transit_gateway_multicast_domain_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.init.delete transit_gateway_multicast_domain_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway_multicast_domain",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    transit_gateway_multicast_domain_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more transit gateway multicast domains.

    Args:
        transit_gateway_multicast_domain_ids(List, optional): The ID of the transit gateway multicast domain. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    state - The state of the transit gateway multicast domain. Valid values are pending | available | deleting | deleted.    transit-gateway-id - The ID of the transit gateway.    transit-gateway-multicast-domain-id - The ID of the transit gateway multicast domain.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateway_multicast_domains",
        op_kwargs={
            "TransitGatewayMulticastDomainIds": transit_gateway_multicast_domain_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )


async def disassociate(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    transit_gateway_attachment_id: str = None,
    subnet_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified subnets from the transit gateway multicast domain.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        transit_gateway_attachment_id(str, optional): The ID of the attachment. Defaults to None.
        subnet_ids(List, optional): The IDs of the subnets;. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.init.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.init.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_transit_gateway_multicast_domain",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "SubnetIds": subnet_ids,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, studio_id: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Repairs the SSO configuration for a given studio. If the studio has a valid AWS SSO configuration currently associated with it, this operation will fail with a validation error. If the studio does not have a valid AWS SSO configuration currently associated with it, then a new AWS SSO application is created for the studio and the studio is changed to the READY state. After the AWS SSO application is repaired, you must use the Amazon Nimble Studio console to add administrators and users to your studio.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.studio.sso_configuration_repair.start(
                ctx, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.studio.sso_configuration_repair.start studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="start_studio_sso_configuration_repair",
        op_kwargs={"clientToken": client_token, "studioId": studio_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def send(
    hub,
    ctx,
    agent_version: str,
    device_name: str,
    device_fleet_name: str,
    agent_metrics: List = None,
    models: List = None,
) -> None:
    r"""
    **Autogenerated function**

    Use to get the current status of devices registered on SageMaker Edge Manager.

    Args:
        agent_metrics(List, optional): For internal use. Returns a list of SageMaker Edge Manager agent operating metrics. Defaults to None.
        models(List, optional): Returns a list of models deployed on the the device. Defaults to None.
        agent_version(str): Returns the version of the agent.
        device_name(str): The unique name of the device.
        device_fleet_name(str): The name of the fleet that the device belongs to.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker_edge.heartbeat.send(
                ctx, agent_version=value, device_name=value, device_fleet_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker_edge.heartbeat.send agent_version=value, device_name=value, device_fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker-edge",
        operation="send_heartbeat",
        op_kwargs={
            "AgentMetrics": agent_metrics,
            "Models": models,
            "AgentVersion": agent_version,
            "DeviceName": device_name,
            "DeviceFleetName": device_fleet_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified deployment job.

    Args:
        job(str): The deployment job ARN to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.deployment_job.cancel(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.deployment_job.cancel job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="cancel_deployment_job",
        op_kwargs={"job": job},
    )


async def create(
    hub,
    ctx,
    client_request_token: str,
    fleet: str,
    deployment_application_configs: List,
    deployment_config: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deploys a specific version of a robot application to robots in a fleet. The robot application must have a numbered applicationVersion for consistency reasons. To create a new version, use CreateRobotApplicationVersion or see Creating a Robot Application Version.   After 90 days, deployment jobs expire and will be deleted. They will no longer be accessible.

    Args:
        deployment_config(Dict, optional): The requested deployment configuration. Defaults to None.
        client_request_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        fleet(str): The Amazon Resource Name (ARN) of the fleet to deploy.
        deployment_application_configs(List): The deployment application configuration.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the deployment job. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.deployment_job.create(
                ctx, client_request_token=value, fleet=value, deployment_application_configs=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.deployment_job.create client_request_token=value, fleet=value, deployment_application_configs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_deployment_job",
        op_kwargs={
            "deploymentConfig": deployment_config,
            "clientRequestToken": client_request_token,
            "fleet": fleet,
            "deploymentApplicationConfigs": deployment_application_configs,
            "tags": tags,
        },
    )


async def describe(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a deployment job.

    Args:
        job(str): The Amazon Resource Name (ARN) of the deployment job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.deployment_job.describe(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.deployment_job.describe job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_deployment_job",
        op_kwargs={"job": job},
    )


async def list_all(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of deployment jobs for a fleet. You can optionally provide filters to retrieve specific deployment jobs.

    Args:
        filters(List, optional): Optional filters to limit results. The filter names status and fleetName are supported. When filtering, you must use the complete value of the filtered item. You can use up to three filters, but they must be for the same named item. For example, if you are looking for items with the status InProgress or the status Pending. Defaults to None.
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListDeploymentJobs again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListDeploymentJobs only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListDeploymentJobs request with the returned nextToken value. This value can be between 1 and 200. If this parameter is not used, then ListDeploymentJobs returns up to 200 results and a nextToken value if applicable. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.deployment_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.deployment_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_deployment_jobs",
        op_kwargs={
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def sync(hub, ctx, client_request_token: str, fleet: str) -> Dict:
    r"""
    **Autogenerated function**

    Syncrhonizes robots in a fleet to the latest deployment. This is helpful if robots were added after a deployment.

    Args:
        client_request_token(str): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        fleet(str): The target fleet for the synchronization.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.deployment_job.sync(
                ctx, client_request_token=value, fleet=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.deployment_job.sync client_request_token=value, fleet=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="sync_deployment_job",
        op_kwargs={"clientRequestToken": client_request_token, "fleet": fleet},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    created_artifact: Dict,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a created artifact of an AWS cloud resource, the target receiving the migration, with the migration task performed by a migration tool. This API has the following traits:   Migration tools can call the AssociateCreatedArtifact operation to indicate which AWS artifact is associated with a migration task.   The created artifact name must be provided in ARN (Amazon Resource Name) format which will contain information about type and region; for example: arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b.   Examples of the AWS resource behind the created artifact are, AMI's, EC2 instance, or DMS endpoint, etc.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream. .
        migration_task_name(str): Unique identifier that references the migration task. Do not store personal data in this field. .
        created_artifact(Dict): An ARN of the AWS resource related to the migration (e.g., AMI, EC2 instance, RDS instance, etc.) .
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.created_artifact.associate(
                ctx, progress_update_stream=value, migration_task_name=value, created_artifact=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.created_artifact.associate progress_update_stream=value, migration_task_name=value, created_artifact=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="associate_created_artifact",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "CreatedArtifact": created_artifact,
            "DryRun": dry_run,
        },
    )


async def disassociate(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    created_artifact_name: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a created artifact of an AWS resource with a migration task performed by a migration tool that was previously associated. This API has the following traits:   A migration user can call the DisassociateCreatedArtifacts operation to disassociate a created AWS Artifact from a migration task.   The created artifact name must be provided in ARN (Amazon Resource Name) format which will contain information about type and region; for example: arn:aws:ec2:us-east-1:488216288981:image/ami-6d0ba87b.   Examples of the AWS resource behind the created artifact are, AMI's, EC2 instance, or RDS instance, etc.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream. .
        migration_task_name(str): Unique identifier that references the migration task to be disassociated with the artifact. Do not store personal data in this field. .
        created_artifact_name(str): An ARN of the AWS resource related to the migration (e.g., AMI, EC2 instance, RDS instance, etc.).
        dry_run(bool, optional): Optional boolean flag to indicate whether any effect should take place. Used to test if the caller has permission to make the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.created_artifact.disassociate(
                ctx,
                progress_update_stream=value,
                migration_task_name=value,
                created_artifact_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.created_artifact.disassociate progress_update_stream=value, migration_task_name=value, created_artifact_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="disassociate_created_artifact",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "CreatedArtifactName": created_artifact_name,
            "DryRun": dry_run,
        },
    )


async def list_all(
    hub,
    ctx,
    progress_update_stream: str,
    migration_task_name: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the created artifacts attached to a given migration task in an update stream. This API has the following traits:   Gets the list of the created artifacts while migration is taking place.   Shows the artifacts created by the migration tool that was associated by the AssociateCreatedArtifact API.    Lists created artifacts in a paginated interface.

    Args:
        progress_update_stream(str): The name of the ProgressUpdateStream. .
        migration_task_name(str): Unique identifier that references the migration task. Do not store personal data in this field. .
        next_token(str, optional): If a NextToken was returned by a previous call, there are more results available. To retrieve the next page of results, make the call again using the returned token in NextToken. Defaults to None.
        max_results(int, optional): Maximum number of results to be returned per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgh.created_artifact.list_all(
                ctx, progress_update_stream=value, migration_task_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgh.created_artifact.list_all progress_update_stream=value, migration_task_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgh",
        operation="list_created_artifacts",
        op_kwargs={
            "ProgressUpdateStream": progress_update_stream,
            "MigrationTaskName": migration_task_name,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    destination_cidr_block: str,
    transit_gateway_route_table_id: str,
    transit_gateway_attachment_id: str = None,
    blackhole: bool = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a static route for the specified transit gateway route table.

    Args:
        destination_cidr_block(str): The CIDR range used for destination matches. Routing decisions are based on the most specific match.
        transit_gateway_route_table_id(str): The ID of the transit gateway route table.
        transit_gateway_attachment_id(str, optional): The ID of the attachment. Defaults to None.
        blackhole(bool, optional): Indicates whether to drop traffic that matches this route. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.init.create(
                ctx, destination_cidr_block=value, transit_gateway_route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.init.create destination_cidr_block=value, transit_gateway_route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway_route",
        op_kwargs={
            "DestinationCidrBlock": destination_cidr_block,
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "Blackhole": blackhole,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    destination_cidr_block: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified route from the specified transit gateway route table.

    Args:
        transit_gateway_route_table_id(str): The ID of the transit gateway route table.
        destination_cidr_block(str): The CIDR range for the route. This must match the CIDR for the route exactly.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.init.delete(
                ctx, transit_gateway_route_table_id=value, destination_cidr_block=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.init.delete transit_gateway_route_table_id=value, destination_cidr_block=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway_route",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "DestinationCidrBlock": destination_cidr_block,
            "DryRun": dry_run,
        },
    )


async def export(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    s3_bucket: str,
    filters: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports routes from the specified transit gateway route table to the specified S3 bucket. By default, all routes are exported. Alternatively, you can filter by CIDR range. The routes are saved to the specified bucket in a JSON file. For more information, see Export Route Tables to Amazon S3 in Transit Gateways.

    Args:
        transit_gateway_route_table_id(str): The ID of the route table.
        filters(List, optional): One or more filters. The possible values are:    attachment.transit-gateway-attachment-id - The id of the transit gateway attachment.    attachment.resource-id - The resource id of the transit gateway attachment.    route-search.exact-match - The exact match of the specified filter.    route-search.longest-prefix-match - The longest prefix that matches the route.    route-search.subnet-of-match - The routes with a subnet that match the specified CIDR filter.    route-search.supernet-of-match - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify supernet-of-match as 10.0.1.0/30, then the result returns 10.0.1.0/29.    state - The state of the route (active | blackhole).    transit-gateway-route-destination-cidr-block - The CIDR range.    type - The type of route (propagated | static).  . Defaults to None.
        s3_bucket(str): The name of the S3 bucket.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.init.export(
                ctx, transit_gateway_route_table_id=value, s3_bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.init.export transit_gateway_route_table_id=value, s3_bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="export_transit_gateway_routes",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "Filters": filters,
            "S3Bucket": s3_bucket,
            "DryRun": dry_run,
        },
    )


async def replace(
    hub,
    ctx,
    destination_cidr_block: str,
    transit_gateway_route_table_id: str,
    transit_gateway_attachment_id: str = None,
    blackhole: bool = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the specified route in the specified transit gateway route table.

    Args:
        destination_cidr_block(str): The CIDR range used for the destination match. Routing decisions are based on the most specific match.
        transit_gateway_route_table_id(str): The ID of the route table.
        transit_gateway_attachment_id(str, optional): The ID of the attachment. Defaults to None.
        blackhole(bool, optional): Indicates whether traffic matching this route is to be dropped. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.init.replace(
                ctx, destination_cidr_block=value, transit_gateway_route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.init.replace destination_cidr_block=value, transit_gateway_route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="replace_transit_gateway_route",
        op_kwargs={
            "DestinationCidrBlock": destination_cidr_block,
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "Blackhole": blackhole,
            "DryRun": dry_run,
        },
    )


async def search(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    filters: List,
    max_results: int = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for routes in the specified transit gateway route table.

    Args:
        transit_gateway_route_table_id(str): The ID of the transit gateway route table.
        filters(List): One or more filters. The possible values are:    attachment.transit-gateway-attachment-id- The id of the transit gateway attachment.    attachment.resource-id - The resource id of the transit gateway attachment.    attachment.resource-type - The attachment resource type. Valid values are vpc | vpn | direct-connect-gateway | peering | connect.    prefix-list-id - The ID of the prefix list.    route-search.exact-match - The exact match of the specified filter.    route-search.longest-prefix-match - The longest prefix that matches the route.    route-search.subnet-of-match - The routes with a subnet that match the specified CIDR filter.    route-search.supernet-of-match - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify supernet-of-match as 10.0.1.0/30, then the result returns 10.0.1.0/29.    state - The state of the route (active | blackhole).    type - The type of route (propagated | static).  .
        max_results(int, optional): The maximum number of routes to return. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.init.search(
                ctx, transit_gateway_route_table_id=value, filters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.init.search transit_gateway_route_table_id=value, filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="search_transit_gateway_routes",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "Filters": filters,
            "MaxResults": max_results,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    associate_default_security_group: bool,
    bandwidth_throttling: int,
    create_public_ip: bool,
    data_plane_routing: str,
    default_large_staging_disk_type: str,
    ebs_encryption: str,
    replication_server_instance_type: str,
    replication_servers_security_groups_i_ds: List,
    staging_area_subnet_id: str,
    staging_area_tags: Dict,
    use_dedicated_replication_server: bool,
    ebs_encryption_key_arn: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new ReplicationConfigurationTemplate.

    Args:
        associate_default_security_group(bool): Request to associate the default Application Migration Service Security group with the Replication Settings template.
        bandwidth_throttling(int): Request to configure bandwidth throttling during Replication Settings template creation.
        create_public_ip(bool): Request to create Public IP during Replication Settings template creation.
        data_plane_routing(str): Request to configure data plane routing during Replication Settings template creation.
        default_large_staging_disk_type(str): Request to configure the Staging Disk EBS volume type to "gp2" during Replication Settings template creation.
        ebs_encryption(str): Request to configure EBS enryption during Replication Settings template creation.
        ebs_encryption_key_arn(str, optional): Request to configure an EBS enryption key during Replication Settings template creation. Defaults to None.
        replication_server_instance_type(str): Request to configure the Replication Server instance type during Replication Settings template creation.
        replication_servers_security_groups_i_ds(List): Request to configure the Replication Server Secuirity group ID during Replication Settings template creation.
        staging_area_subnet_id(str): Request to configure the Staging Area subnet ID during Replication Settings template creation.
        staging_area_tags(Dict): Request to configure Staiging Area tags during Replication Settings template creation.
        tags(Dict, optional): Request to configure tags during Replication Settings template creation. Defaults to None.
        use_dedicated_replication_server(bool): Request to use Dedicated Replication Servers during Replication Settings template creation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.replication_configuration.template.create(
                ctx,
                associate_default_security_group=value,
                bandwidth_throttling=value,
                create_public_ip=value,
                data_plane_routing=value,
                default_large_staging_disk_type=value,
                ebs_encryption=value,
                replication_server_instance_type=value,
                replication_servers_security_groups_i_ds=value,
                staging_area_subnet_id=value,
                staging_area_tags=value,
                use_dedicated_replication_server=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.replication_configuration.template.create associate_default_security_group=value, bandwidth_throttling=value, create_public_ip=value, data_plane_routing=value, default_large_staging_disk_type=value, ebs_encryption=value, replication_server_instance_type=value, replication_servers_security_groups_i_ds=value, staging_area_subnet_id=value, staging_area_tags=value, use_dedicated_replication_server=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="create_replication_configuration_template",
        op_kwargs={
            "associateDefaultSecurityGroup": associate_default_security_group,
            "bandwidthThrottling": bandwidth_throttling,
            "createPublicIP": create_public_ip,
            "dataPlaneRouting": data_plane_routing,
            "defaultLargeStagingDiskType": default_large_staging_disk_type,
            "ebsEncryption": ebs_encryption,
            "ebsEncryptionKeyArn": ebs_encryption_key_arn,
            "replicationServerInstanceType": replication_server_instance_type,
            "replicationServersSecurityGroupsIDs": replication_servers_security_groups_i_ds,
            "stagingAreaSubnetId": staging_area_subnet_id,
            "stagingAreaTags": staging_area_tags,
            "tags": tags,
            "useDedicatedReplicationServer": use_dedicated_replication_server,
        },
    )


async def delete(hub, ctx, replication_configuration_template_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a single Replication Configuration Template by ID

    Args:
        replication_configuration_template_id(str): Request to delete Replication Configuration Template from service by Replication Configuration Template ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.replication_configuration.template.delete(
                ctx, replication_configuration_template_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.replication_configuration.template.delete replication_configuration_template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="delete_replication_configuration_template",
        op_kwargs={
            "replicationConfigurationTemplateID": replication_configuration_template_id
        },
    )


async def describe_all(
    hub,
    ctx,
    replication_configuration_template_i_ds: List,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.

    Args:
        max_results(int, optional): Request to describe Replication Configuration template by max results. Defaults to None.
        next_token(str, optional): Request to describe Replication Configuration template by next token. Defaults to None.
        replication_configuration_template_i_ds(List): Request to describe Replication Configuration template by template IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.replication_configuration.template.describe_all(
                ctx, replication_configuration_template_i_ds=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.replication_configuration.template.describe_all replication_configuration_template_i_ds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="describe_replication_configuration_templates",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "replicationConfigurationTemplateIDs": replication_configuration_template_i_ds,
        },
    )


async def update(
    hub,
    ctx,
    replication_configuration_template_id: str,
    arn: str = None,
    associate_default_security_group: bool = None,
    bandwidth_throttling: int = None,
    create_public_ip: bool = None,
    data_plane_routing: str = None,
    default_large_staging_disk_type: str = None,
    ebs_encryption: str = None,
    ebs_encryption_key_arn: str = None,
    replication_server_instance_type: str = None,
    replication_servers_security_groups_i_ds: List = None,
    staging_area_subnet_id: str = None,
    staging_area_tags: Dict = None,
    use_dedicated_replication_server: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates multiple ReplicationConfigurationTemplates by ID.

    Args:
        arn(str, optional): Update replication configuration template ARN request. Defaults to None.
        associate_default_security_group(bool, optional): Update replication configuration template associate default Application Migration Service Security group request. Defaults to None.
        bandwidth_throttling(int, optional): Update replication configuration template bandwidth throttling request. Defaults to None.
        create_public_ip(bool, optional): Update replication configuration template create Public IP request. Defaults to None.
        data_plane_routing(str, optional): Update replication configuration template data plane routing request. Defaults to None.
        default_large_staging_disk_type(str, optional): Update replication configuration template use default large Staging Disk type request. Defaults to None.
        ebs_encryption(str, optional): Update replication configuration template EBS encryption request. Defaults to None.
        ebs_encryption_key_arn(str, optional): Update replication configuration template EBS encryption key ARN request. Defaults to None.
        replication_configuration_template_id(str): Update replication configuration template template ID request.
        replication_server_instance_type(str, optional): Update replication configuration template Replication Server instance type request. Defaults to None.
        replication_servers_security_groups_i_ds(List, optional): Update replication configuration template Replication Server Security groups IDs request. Defaults to None.
        staging_area_subnet_id(str, optional): Update replication configuration template Staging Area subnet ID request. Defaults to None.
        staging_area_tags(Dict, optional): Update replication configuration template Staging Area Tags request. Defaults to None.
        use_dedicated_replication_server(bool, optional): Update replication configuration template use dedicated Replication Server request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.replication_configuration.template.update(
                ctx, replication_configuration_template_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.replication_configuration.template.update replication_configuration_template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="update_replication_configuration_template",
        op_kwargs={
            "arn": arn,
            "associateDefaultSecurityGroup": associate_default_security_group,
            "bandwidthThrottling": bandwidth_throttling,
            "createPublicIP": create_public_ip,
            "dataPlaneRouting": data_plane_routing,
            "defaultLargeStagingDiskType": default_large_staging_disk_type,
            "ebsEncryption": ebs_encryption,
            "ebsEncryptionKeyArn": ebs_encryption_key_arn,
            "replicationConfigurationTemplateID": replication_configuration_template_id,
            "replicationServerInstanceType": replication_server_instance_type,
            "replicationServersSecurityGroupsIDs": replication_servers_security_groups_i_ds,
            "stagingAreaSubnetId": staging_area_subnet_id,
            "stagingAreaTags": staging_area_tags,
            "useDedicatedReplicationServer": use_dedicated_replication_server,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    client_request_token: str = None,
    name: str = None,
    template_body: str = None,
    template_location: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a world template.

    Args:
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        name(str, optional): The name of the world template. Defaults to None.
        template_body(str, optional): The world template body. Defaults to None.
        template_location(Dict, optional): The location of the world template. Defaults to None.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the world template. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.template.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.template.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_world_template",
        op_kwargs={
            "clientRequestToken": client_request_token,
            "name": name,
            "templateBody": template_body,
            "templateLocation": template_location,
            "tags": tags,
        },
    )


async def delete(hub, ctx, template: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a world template.

    Args:
        template(str): The Amazon Resource Name (arn) of the world template you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.template.init.delete(ctx, template=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.template.init.delete template=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="delete_world_template",
        op_kwargs={"template": template},
    )


async def describe(hub, ctx, template: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a world template.

    Args:
        template(str): The Amazon Resource Name (arn) of the world template you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.template.init.describe(ctx, template=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.template.init.describe template=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_world_template",
        op_kwargs={"template": template},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists world templates.

    Args:
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListWorldTemplates again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListWorldTemplates only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListWorldTemplates request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListWorldTemplates returns up to 100 results and a nextToken value if applicable. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.template.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.template.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_world_templates",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    template: str,
    name: str = None,
    template_body: str = None,
    template_location: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a world template.

    Args:
        template(str): The Amazon Resource Name (arn) of the world template to update.
        name(str, optional): The name of the template. Defaults to None.
        template_body(str, optional): The world template body. Defaults to None.
        template_location(Dict, optional): The location of the world template. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.world.template.init.update(ctx, template=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.world.template.init.update template=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="update_world_template",
        op_kwargs={
            "template": template,
            "name": name,
            "templateBody": template_body,
            "templateLocation": template_location,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Cancels a Device Defender ML Detect mitigation action.

    Args:
        task_id(str):  The unique identifier of the task. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.detect_mitigation_action.task.cancel(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.detect_mitigation_action.task.cancel task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="cancel_detect_mitigation_actions_task",
        op_kwargs={"taskId": task_id},
    )


async def describe(hub, ctx, task_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets information about a Device Defender ML Detect mitigation action.

    Args:
        task_id(str):  The unique identifier of the task. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.detect_mitigation_action.task.describe(ctx, task_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.detect_mitigation_action.task.describe task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_detect_mitigation_actions_task",
        op_kwargs={"taskId": task_id},
    )


async def list_all(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     List of Device Defender ML Detect mitigation actions tasks.

    Args:
        max_results(int, optional): The maximum number of results to return at one time. The default is 25. Defaults to None.
        next_token(str, optional):  The token for the next set of results. . Defaults to None.
        start_time(str):  A filter to limit results to those found after the specified time. You must specify either the startTime and endTime or the taskId, but not both. .
        end_time(str):  The end of the time period for which ML Detect mitigation actions tasks are returned. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.detect_mitigation_action.task.list_all(
                ctx, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.detect_mitigation_action.task.list_all start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_detect_mitigation_actions_tasks",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "startTime": start_time,
            "endTime": end_time,
        },
    )


async def start(
    hub,
    ctx,
    task_id: str,
    target: Dict,
    actions: List,
    client_request_token: str,
    violation_event_occurrence_range: Dict = None,
    include_only_active_violations: bool = None,
    include_suppressed_alerts: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Starts a Device Defender ML Detect mitigation actions task.

    Args:
        task_id(str):  The unique identifier of the task. .
        target(Dict):  Specifies the ML Detect findings to which the mitigation actions are applied. .
        actions(List):  The actions to be performed when a device has unexpected behavior. .
        violation_event_occurrence_range(Dict, optional):  Specifies the time period of which violation events occurred between. . Defaults to None.
        include_only_active_violations(bool, optional):  Specifies to list only active violations. . Defaults to None.
        include_suppressed_alerts(bool, optional):  Specifies to include suppressed alerts. . Defaults to None.
        client_request_token(str):  Each mitigation action task must have a unique client request token. If you try to create a new task with the same token as a task that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.detect_mitigation_action.task.start(
                ctx, task_id=value, target=value, actions=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.detect_mitigation_action.task.start task_id=value, target=value, actions=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="start_detect_mitigation_actions_task",
        op_kwargs={
            "taskId": task_id,
            "target": target,
            "actions": actions,
            "violationEventOccurrenceRange": violation_event_occurrence_range,
            "includeOnlyActiveViolations": include_only_active_violations,
            "includeSuppressedAlerts": include_suppressed_alerts,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    cluster_id: str,
    instance_group_id: str = None,
    instance_group_types: List = None,
    instance_fleet_id: str = None,
    instance_fleet_type: str = None,
    instance_states: List = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides information for all active EC2 instances and EC2 instances terminated in the last 30 days, up to a maximum of 2,000. EC2 instances in any of the following states are considered active: AWAITING_FULFILLMENT, PROVISIONING, BOOTSTRAPPING, RUNNING.

    Args:
        cluster_id(str): The identifier of the cluster for which to list the instances.
        instance_group_id(str, optional): The identifier of the instance group for which to list the instances. Defaults to None.
        instance_group_types(List, optional): The type of instance group for which to list the instances. Defaults to None.
        instance_fleet_id(str, optional): The unique identifier of the instance fleet. Defaults to None.
        instance_fleet_type(str, optional): The node type of the instance fleet. For example MASTER, CORE, or TASK. Defaults to None.
        instance_states(List, optional): A list of instance states that will filter the instances returned with this request. Defaults to None.
        marker(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.instance.init.list_all(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.instance.init.list_all cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_instances",
        op_kwargs={
            "ClusterId": cluster_id,
            "InstanceGroupId": instance_group_id,
            "InstanceGroupTypes": instance_group_types,
            "InstanceFleetId": instance_fleet_id,
            "InstanceFleetType": instance_fleet_type,
            "InstanceStates": instance_states,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def copy(
    hub,
    ctx,
    target_snapshot_name: str,
    source_region: str,
    source_snapshot_name: str = None,
    source_resource_name: str = None,
    restore_date: str = None,
    use_latest_restorable_auto_snapshot: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies a manual snapshot of an instance or disk as another manual snapshot, or copies an automatic snapshot of an instance or disk as a manual snapshot. This operation can also be used to copy a manual or automatic snapshot of an instance or a disk from one AWS Region to another in Amazon Lightsail. When copying a manual snapshot, be sure to define the source region, source snapshot name, and target snapshot name parameters. When copying an automatic snapshot, be sure to define the source region, source resource name, target snapshot name, and either the restore date or the use latest restorable auto snapshot parameters.

    Args:
        source_snapshot_name(str, optional): The name of the source manual snapshot to copy. Constraint:   Define this parameter only when copying a manual snapshot as another manual snapshot.  . Defaults to None.
        source_resource_name(str, optional): The name of the source instance or disk from which the source automatic snapshot was created. Constraint:   Define this parameter only when copying an automatic snapshot as a manual snapshot. For more information, see the Amazon Lightsail Developer Guide.  . Defaults to None.
        restore_date(str, optional): The date of the source automatic snapshot to copy. Use the get auto snapshots operation to identify the dates of the available automatic snapshots. Constraints:   Must be specified in YYYY-MM-DD format.   This parameter cannot be defined together with the use latest restorable auto snapshot parameter. The restore date and use latest restorable auto snapshot parameters are mutually exclusive.   Define this parameter only when copying an automatic snapshot as a manual snapshot. For more information, see the Amazon Lightsail Developer Guide.  . Defaults to None.
        use_latest_restorable_auto_snapshot(bool, optional): A Boolean value to indicate whether to use the latest available automatic snapshot of the specified source instance or disk. Constraints:   This parameter cannot be defined together with the restore date parameter. The use latest restorable auto snapshot and restore date parameters are mutually exclusive.   Define this parameter only when copying an automatic snapshot as a manual snapshot. For more information, see the Amazon Lightsail Developer Guide.  . Defaults to None.
        target_snapshot_name(str): The name of the new manual snapshot to be created as a copy.
        source_region(str): The AWS Region where the source manual or automatic snapshot is located.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.snapshot.copy(
                ctx, target_snapshot_name=value, source_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.snapshot.copy target_snapshot_name=value, source_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="copy_snapshot",
        op_kwargs={
            "sourceSnapshotName": source_snapshot_name,
            "sourceResourceName": source_resource_name,
            "restoreDate": restore_date,
            "useLatestRestorableAutoSnapshot": use_latest_restorable_auto_snapshot,
            "targetSnapshotName": target_snapshot_name,
            "sourceRegion": source_region,
        },
    )


async def export(hub, ctx, source_snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Exports an Amazon Lightsail instance or block storage disk snapshot to Amazon Elastic Compute Cloud (Amazon EC2). This operation results in an export snapshot record that can be used with the create cloud formation stack operation to create new Amazon EC2 instances. Exported instance snapshots appear in Amazon EC2 as Amazon Machine Images (AMIs), and the instance system disk appears as an Amazon Elastic Block Store (Amazon EBS) volume. Exported disk snapshots appear in Amazon EC2 as Amazon EBS volumes. Snapshots are exported to the same Amazon Web Services Region in Amazon EC2 as the source Lightsail snapshot.  The export snapshot operation supports tag-based access control via resource tags applied to the resource identified by source snapshot name. For more information, see the Amazon Lightsail Developer Guide.  Use the get instance snapshots or get disk snapshots operations to get a list of snapshots that you can export to Amazon EC2.

    Args:
        source_snapshot_name(str): The name of the instance or disk snapshot to be exported to Amazon EC2.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.snapshot.export(ctx, source_snapshot_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.snapshot.export source_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="export_snapshot",
        op_kwargs={"sourceSnapshotName": source_snapshot_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(
    hub, ctx, load_balancer_name: str, instance_port: int, policy_names: List
) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the set of policies associated with the specified port on which the EC2 instance is listening with a new set of policies. At this time, only the back-end server authentication policy type can be applied to the instance ports; this policy type is composed of multiple public key policies. Each time you use SetLoadBalancerPoliciesForBackendServer to enable the policies, use the PolicyNames parameter to list the policies that you want to enable. You can use DescribeLoadBalancers or DescribeLoadBalancerPolicies to verify that the policy is associated with the EC2 instance. For more information about enabling back-end instance authentication, see Configure Back-end Instance Authentication in the Classic Load Balancers Guide. For more information about Proxy Protocol, see Configure Proxy Protocol Support in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        instance_port(int): The port number associated with the EC2 instance.
        policy_names(List): The names of the policies. If the list is empty, then all current polices are removed from the EC2 instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.policy.for_backend_server.set(
                ctx, load_balancer_name=value, instance_port=value, policy_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.policy.for_backend_server.set load_balancer_name=value, instance_port=value, policy_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="set_load_balancer_policies_for_backend_server",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "InstancePort": instance_port,
            "PolicyNames": policy_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Applies tag values to a behavior graph.

    Args:
        resource_arn(str): The ARN of the behavior graph to assign the tags to.
        tags(Dict): The tags to assign to the behavior graph. You can add up to 50 tags. For each tag, you provide the tag key and the tag value. Each tag key can contain up to 128 characters. Each tag value can contain up to 256 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from a behavior graph.

    Args:
        resource_arn(str): The ARN of the behavior graph to remove the tags from.
        tag_keys(List): The tag keys of the tags to remove from the behavior graph. You can remove up to 50 tags at a time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(
    hub, ctx, instance_id: str, routing_profile_id: str, default_outbound_queue_id: str
) -> None:
    r"""
    **Autogenerated function**

    Updates the default outbound queue of a routing profile.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        routing_profile_id(str): The identifier of the routing profile.
        default_outbound_queue_id(str): The identifier for the default outbound queue.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.default_outbound_queue.update(
                ctx, instance_id=value, routing_profile_id=value, default_outbound_queue_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.default_outbound_queue.update instance_id=value, routing_profile_id=value, default_outbound_queue_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_routing_profile_default_outbound_queue",
        op_kwargs={
            "InstanceId": instance_id,
            "RoutingProfileId": routing_profile_id,
            "DefaultOutboundQueueId": default_outbound_queue_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, thing_name: str, next_token: str = None, page_size: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the shadows for the specified thing.

    Args:
        thing_name(str): The name of the thing.
        next_token(str, optional): The token to retrieve the next set of results. Defaults to None.
        page_size(int, optional): The result page size. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot_data.named_shadow_for_thing.list(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot_data.named_shadow_for_thing.list thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot-data",
        operation="list_named_shadows_for_thing",
        op_kwargs={
            "thingName": thing_name,
            "nextToken": next_token,
            "pageSize": page_size,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put(hub, ctx, delivery_stream_name: str, records: List) -> Dict:
    r"""
    **Autogenerated function**

    Writes multiple data records into a delivery stream in a single call, which can achieve higher throughput per producer than when writing single records. To write single data records into a delivery stream, use PutRecord. Applications using these operations are referred to as producers. For information about service quota, see Amazon Kinesis Data Firehose Quota. Each PutRecordBatch request supports up to 500 records. Each record in the request can be as large as 1,000 KB (before 64-bit encoding), up to a limit of 4 MB for the entire request. These limits cannot be changed. You must specify the name of the delivery stream and the data record when using PutRecord. The data record consists of a data blob that can be up to 1,000 KB in size, and any kind of data. For example, it could be a segment from a log file, geographic location data, website clickstream data, and so on. Kinesis Data Firehose buffers records before delivering them to the destination. To disambiguate the data blobs at the destination, a common solution is to use delimiters in the data, such as a newline (\n) or some other character unique within the data. This allows the consumer application to parse individual data items when reading the data from the destination. The PutRecordBatch response includes a count of failed records, FailedPutCount, and an array of responses, RequestResponses. Even if the PutRecordBatch call succeeds, the value of FailedPutCount may be greater than 0, indicating that there are records for which the operation didn't succeed. Each entry in the RequestResponses array provides additional information about the processed record. It directly correlates with a record in the request array using the same ordering, from the top to the bottom. The response array always includes the same number of records as the request array. RequestResponses includes both successfully and unsuccessfully processed records. Kinesis Data Firehose tries to process all records in each PutRecordBatch request. A single record failure does not stop the processing of subsequent records.  A successfully processed record includes a RecordId value, which is unique for the record. An unsuccessfully processed record includes ErrorCode and ErrorMessage values. ErrorCode reflects the type of error, and is one of the following values: ServiceUnavailableException or InternalFailure. ErrorMessage provides more detailed information about the error. If there is an internal server error or a timeout, the write might have completed or it might have failed. If FailedPutCount is greater than 0, retry the request, resending only those records that might have failed processing. This minimizes the possible duplicate records and also reduces the total bytes sent (and corresponding charges). We recommend that you handle any duplicates at the destination. If PutRecordBatch throws ServiceUnavailableException, back off and retry. If the exception persists, it is possible that the throughput limits have been exceeded for the delivery stream. Data records sent to Kinesis Data Firehose are stored for 24 hours from the time they are added to a delivery stream as it attempts to send the records to the destination. If the destination is unreachable for more than 24 hours, the data is no longer available.  Don't concatenate two or more base64 strings to form the data fields of your records. Instead, concatenate the raw data, then perform base64 encoding.

    Args:
        delivery_stream_name(str): The name of the delivery stream.
        records(List): One or more records.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.firehose.record.batch.put(
                ctx, delivery_stream_name=value, records=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.firehose.record.batch.put delivery_stream_name=value, records=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="firehose",
        operation="put_record_batch",
        op_kwargs={"DeliveryStreamName": delivery_stream_name, "Records": records},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, node_association_status_token: str, server_name: str
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the current status of an existing association or disassociation request.   A ResourceNotFoundException is thrown when no recent association or disassociation request with the specified token is found, or when the server does not exist. A ValidationException is raised when parameters of the request are not valid.

    Args:
        node_association_status_token(str): The token returned in either the AssociateNodeResponse or the DisassociateNodeResponse. .
        server_name(str): The name of the server from which to disassociate the node. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opsworkscm.node.association_status.describe(
                ctx, node_association_status_token=value, server_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opsworkscm.node.association_status.describe node_association_status_token=value, server_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworkscm",
        operation="describe_node_association_status",
        op_kwargs={
            "NodeAssociationStatusToken": node_association_status_token,
            "ServerName": server_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(hub, ctx, replication_task_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Starts the replication task assessment for unsupported data types in the source database.

    Args:
        replication_task_arn(str):  The Amazon Resource Name (ARN) of the replication task. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.assessment.init.start(
                ctx, replication_task_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.assessment.init.start replication_task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="start_replication_task_assessment",
        op_kwargs={"ReplicationTaskArn": replication_task_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the most recent high availability monitoring test that was performed on the host in a cluster. If a test isn't performed, the status and start time in the response would be null.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.availability_monitor_test.describe(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.availability_monitor_test.describe gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_availability_monitor_test",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def start(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Start a test that verifies that the specified gateway is configured for High Availability monitoring in your host environment. This request only initiates the test and that a successful response only indicates that the test was started. It doesn't indicate that the test passed. For the status of the test, invoke the DescribeAvailabilityMonitorTest API.  Starting this test will cause your gateway to go offline for a brief period.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.availability_monitor_test.start(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.availability_monitor_test.start gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="start_availability_monitor_test",
        op_kwargs={"GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    usage_plan_id: str,
    start_date: str,
    end_date: str,
    key_id: str = None,
    position: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the usage data of a usage plan in a specified time interval.

    Args:
        usage_plan_id(str): [Required] The Id of the usage plan associated with the usage data.
        key_id(str, optional): The Id of the API key associated with the resultant usage data. Defaults to None.
        start_date(str): [Required] The starting date (e.g., 2016-01-01) of the usage data.
        end_date(str): [Required] The ending date (e.g., 2016-12-31) of the usage data.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.init.get(
                ctx, usage_plan_id=value, start_date=value, end_date=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.init.get usage_plan_id=value, start_date=value, end_date=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_usage",
        op_kwargs={
            "usagePlanId": usage_plan_id,
            "keyId": key_id,
            "startDate": start_date,
            "endDate": end_date,
            "position": position,
            "limit": limit,
        },
    )


async def update(
    hub, ctx, usage_plan_id: str, key_id: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Grants a temporary extension to the remaining quota of a usage plan associated with a specified API key.

    Args:
        usage_plan_id(str): [Required] The Id of the usage plan associated with the usage data.
        key_id(str): [Required] The identifier of the API key associated with the usage plan in which a temporary extension is granted to the remaining quota.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.usage.init.update(
                ctx, usage_plan_id=value, key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.usage.init.update usage_plan_id=value, key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_usage",
        op_kwargs={
            "usagePlanId": usage_plan_id,
            "keyId": key_id,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    device_pool_arn: str,
    app_arn: str = None,
    test_type: str = None,
    test: Dict = None,
    configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about compatibility with a device pool.

    Args:
        device_pool_arn(str): The device pool's ARN.
        app_arn(str, optional): The ARN of the app that is associated with the specified device pool. Defaults to None.
        test_type(str, optional): The test type for the specified device pool. Allowed values include the following:   BUILTIN_FUZZ.   BUILTIN_EXPLORER. For Android, an app explorer that traverses an Android app, interacting with it and capturing screenshots at the same time.   APPIUM_JAVA_JUNIT.   APPIUM_JAVA_TESTNG.   APPIUM_PYTHON.   APPIUM_NODE.   APPIUM_RUBY.   APPIUM_WEB_JAVA_JUNIT.   APPIUM_WEB_JAVA_TESTNG.   APPIUM_WEB_PYTHON.   APPIUM_WEB_NODE.   APPIUM_WEB_RUBY.   CALABASH.   INSTRUMENTATION.   UIAUTOMATION.   UIAUTOMATOR.   XCTEST.   XCTEST_UI.  . Defaults to None.
        test(Dict, optional): Information about the uploaded test to be run against the device pool. Defaults to None.
        configuration(Dict, optional): An object that contains information about the settings for a run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.device.pool.compatibility.get(
                ctx, device_pool_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.device.pool.compatibility.get device_pool_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_device_pool_compatibility",
        op_kwargs={
            "devicePoolArn": device_pool_arn,
            "appArn": app_arn,
            "testType": test_type,
            "test": test,
            "configuration": configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def disable(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    transit_gateway_attachment_id: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disables the specified resource attachment from propagating routes to the specified propagation route table.

    Args:
        transit_gateway_route_table_id(str): The ID of the propagation route table.
        transit_gateway_attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.propagation.disable(
                ctx, transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.propagation.disable transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disable_transit_gateway_route_table_propagation",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def enable(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    transit_gateway_attachment_id: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Enables the specified attachment to propagate routes to the specified propagation route table.

    Args:
        transit_gateway_route_table_id(str): The ID of the propagation route table.
        transit_gateway_attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.propagation.enable(
                ctx, transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.propagation.enable transit_gateway_route_table_id=value, transit_gateway_attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_transit_gateway_route_table_propagation",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "DryRun": dry_run,
        },
    )


async def get_all(
    hub,
    ctx,
    transit_gateway_route_table_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the route table propagations for the specified transit gateway route table.

    Args:
        transit_gateway_route_table_id(str): The ID of the transit gateway route table.
        filters(List, optional): One or more filters. The possible values are:    resource-id - The ID of the resource.    resource-type - The resource type. Valid values are vpc | vpn | direct-connect-gateway | peering | connect.    transit-gateway-attachment-id - The ID of the attachment.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.route.table.propagation.get_all(
                ctx, transit_gateway_route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.route.table.propagation.get_all transit_gateway_route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_transit_gateway_route_table_propagations",
        op_kwargs={
            "TransitGatewayRouteTableId": transit_gateway_route_table_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub,
    ctx,
    name: str,
    update_id: str,
    nodegroup_name: str = None,
    addon_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns descriptive information about an update against your Amazon EKS cluster or associated managed node group. When the status of the update is Succeeded, the update is complete. If an update fails, the status is Failed, and an error detail explains the reason for the failure.

    Args:
        name(str): The name of the Amazon EKS cluster associated with the update.
        update_id(str): The ID of the update to describe.
        nodegroup_name(str, optional): The name of the Amazon EKS node group associated with the update. Defaults to None.
        addon_name(str, optional): The name of the add-on. The name must match one of the names returned by  ListAddons . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.update.describe(ctx, name=value, update_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.update.describe name=value, update_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="describe_update",
        op_kwargs={
            "name": name,
            "updateId": update_id,
            "nodegroupName": nodegroup_name,
            "addonName": addon_name,
        },
    )


async def list_all(
    hub,
    ctx,
    name: str,
    nodegroup_name: str = None,
    addon_name: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the updates associated with an Amazon EKS cluster or managed node group in your Amazon Web Services account, in the specified Region.

    Args:
        name(str): The name of the Amazon EKS cluster to list updates for.
        nodegroup_name(str, optional): The name of the Amazon EKS managed node group to list updates for. Defaults to None.
        addon_name(str, optional): The names of the installed add-ons that have available updates. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListUpdates request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.
        max_results(int, optional): The maximum number of update results returned by ListUpdates in paginated output. When you use this parameter, ListUpdates returns only maxResults results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListUpdates request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListUpdates returns up to 100 results and a nextToken value if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.update.list_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.update.list_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="list_updates",
        op_kwargs={
            "name": name,
            "nodegroupName": nodegroup_name,
            "addonName": addon_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    trial_name: str,
    experiment_name: str,
    display_name: str = None,
    metadata_properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an SageMaker trial. A trial is a set of steps called trial components that produce a machine learning model. A trial is part of a single SageMaker experiment. When you use SageMaker Studio or the SageMaker Python SDK, all experiments, trials, and trial components are automatically tracked, logged, and indexed. When you use the Amazon Web Services SDK for Python (Boto), you must use the logging APIs provided by the SDK. You can add tags to a trial and then use the Search API to search for the tags. To get a list of all your trials, call the ListTrials API. To view a trial's properties, call the DescribeTrial API. To create a trial component, call the CreateTrialComponent API.

    Args:
        trial_name(str): The name of the trial. The name must be unique in your Amazon Web Services account and is not case-sensitive.
        display_name(str, optional): The name of the trial as displayed. The name doesn't need to be unique. If DisplayName isn't specified, TrialName is displayed. Defaults to None.
        experiment_name(str): The name of the experiment to associate the trial with.
        metadata_properties(Dict, optional): Metadata properties of the tracking entity, trial, or trial component. Defaults to None.
        tags(List, optional): A list of tags to associate with the trial. You can use Search API to search on the tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.trial.init.create(
                ctx, trial_name=value, experiment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.trial.init.create trial_name=value, experiment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_trial",
        op_kwargs={
            "TrialName": trial_name,
            "DisplayName": display_name,
            "ExperimentName": experiment_name,
            "MetadataProperties": metadata_properties,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, trial_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified trial. All trial components that make up the trial must be deleted first. Use the DescribeTrialComponent API to get the list of trial components.

    Args:
        trial_name(str): The name of the trial to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.trial.init.delete(ctx, trial_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.trial.init.delete trial_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_trial",
        op_kwargs={"TrialName": trial_name},
    )


async def describe(hub, ctx, trial_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of a trial's properties.

    Args:
        trial_name(str): The name of the trial to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.trial.init.describe(ctx, trial_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.trial.init.describe trial_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_trial",
        op_kwargs={"TrialName": trial_name},
    )


async def list_all(
    hub,
    ctx,
    experiment_name: str = None,
    trial_component_name: str = None,
    created_after: str = None,
    created_before: str = None,
    sort_by: str = None,
    sort_order: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the trials in your account. Specify an experiment name to limit the list to the trials that are part of that experiment. Specify a trial component name to limit the list to the trials that associated with that trial component. The list can be filtered to show only trials that were created in a specific time range. The list can be sorted by trial name or creation time.

    Args:
        experiment_name(str, optional): A filter that returns only trials that are part of the specified experiment. Defaults to None.
        trial_component_name(str, optional): A filter that returns only trials that are associated with the specified trial component. Defaults to None.
        created_after(str, optional): A filter that returns only trials created after the specified time. Defaults to None.
        created_before(str, optional): A filter that returns only trials created before the specified time. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order. The default value is Descending. Defaults to None.
        max_results(int, optional): The maximum number of trials to return in the response. The default value is 10. Defaults to None.
        next_token(str, optional): If the previous call to ListTrials didn't return the full set of trials, the call returns a token for getting the next set of trials. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.trial.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.trial.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_trials",
        op_kwargs={
            "ExperimentName": experiment_name,
            "TrialComponentName": trial_component_name,
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, trial_name: str, display_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the display name of a trial.

    Args:
        trial_name(str): The name of the trial to update.
        display_name(str, optional): The name of the trial as displayed. The name doesn't need to be unique. If DisplayName isn't specified, TrialName is displayed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.trial.init.update(ctx, trial_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.trial.init.update trial_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_trial",
        op_kwargs={"TrialName": trial_name, "DisplayName": display_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of products or offerings that the user can manage through the API. Each offering record indicates the recurring price per unit and the frequency for that offering. The API returns a NotEligible error if the user is not permitted to invoke the operation. If you must be able to invoke this operation, contact aws-devicefarm-support@amazon.com.

    Args:
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.offering.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.offering.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_offerings",
        op_kwargs={"nextToken": next_token},
    )


async def purchase(
    hub, ctx, offering_id: str, quantity: int, offering_promotion_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Immediately purchases offerings for an AWS account. Offerings renew with the latest total purchased quantity for an offering, unless the renewal was overridden. The API returns a NotEligible error if the user is not permitted to invoke the operation. If you must be able to invoke this operation, contact aws-devicefarm-support@amazon.com.

    Args:
        offering_id(str): The ID of the offering.
        quantity(int): The number of device slots to purchase in an offering request.
        offering_promotion_id(str, optional): The ID of the offering promotion to be applied to the purchase. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.offering.init.purchase(
                ctx, offering_id=value, quantity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.offering.init.purchase offering_id=value, quantity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="purchase_offering",
        op_kwargs={
            "offeringId": offering_id,
            "quantity": quantity,
            "offeringPromotionId": offering_promotion_id,
        },
    )


async def renew(hub, ctx, offering_id: str, quantity: int) -> Dict:
    r"""
    **Autogenerated function**

    Explicitly sets the quantity of devices to renew for an offering, starting from the effectiveDate of the next period. The API returns a NotEligible error if the user is not permitted to invoke the operation. If you must be able to invoke this operation, contact aws-devicefarm-support@amazon.com.

    Args:
        offering_id(str): The ID of a request to renew an offering.
        quantity(int): The quantity requested in an offering renewal.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.offering.init.renew(
                ctx, offering_id=value, quantity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.offering.init.renew offering_id=value, quantity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="renew_offering",
        op_kwargs={"offeringId": offering_id, "quantity": quantity},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    engine: str = None,
    engine_version: str = None,
    db_parameter_group_family: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    default_only: bool = None,
    list_supported_character_sets: bool = None,
    list_supported_timezones: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the available engines.

    Args:
        engine(str, optional): The database engine to return. Defaults to None.
        engine_version(str, optional): The database engine version to return. Example: 3.6.0 . Defaults to None.
        db_parameter_group_family(str, optional): The name of a specific parameter group family to return details for. Constraints:   If provided, must match an existing DBParameterGroupFamily.  . Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.
        default_only(bool, optional): Indicates that only the default version of the specified engine or engine and major version combination is returned. Defaults to None.
        list_supported_character_sets(bool, optional): If this parameter is specified and the requested engine supports the CharacterSetName parameter for CreateDBInstance, the response includes a list of supported character sets for each engine version. . Defaults to None.
        list_supported_timezones(bool, optional): If this parameter is specified and the requested engine supports the TimeZone parameter for CreateDBInstance, the response includes a list of supported time zones for each engine version. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.engine_version.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.engine_version.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_db_engine_versions",
        op_kwargs={
            "Engine": engine,
            "EngineVersion": engine_version,
            "DBParameterGroupFamily": db_parameter_group_family,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "DefaultOnly": default_only,
            "ListSupportedCharacterSets": list_supported_character_sets,
            "ListSupportedTimezones": list_supported_timezones,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def describe_all(
    hub, ctx, iam_user_arn: str = None, stack_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the permissions for a specified stack.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        iam_user_arn(str, optional): The user's IAM ARN. This can also be a federated user's ARN. For more information about IAM ARNs, see Using Identifiers. Defaults to None.
        stack_id(str, optional): The stack ID. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.permission.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.permission.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_permissions",
        op_kwargs={"IamUserArn": iam_user_arn, "StackId": stack_id},
    )


async def set_(
    hub,
    ctx,
    stack_id: str,
    iam_user_arn: str,
    allow_ssh: bool = None,
    allow_sudo: bool = None,
    level: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Specifies a user's permissions. For more information, see Security and Permissions.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
        iam_user_arn(str): The user's IAM ARN. This can also be a federated user's ARN.
        allow_ssh(bool, optional): The user is allowed to use SSH to communicate with the instance. Defaults to None.
        allow_sudo(bool, optional): The user is allowed to use sudo to elevate privileges. Defaults to None.
        level(str, optional): The user's permission level, which must be set to one of the following strings. You cannot set your own permissions level.    deny     show     deploy     manage     iam_only    For more information about the permissions associated with these levels, see Managing User Permissions. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.permission.set(ctx, stack_id=value, iam_user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.permission.set stack_id=value, iam_user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="set_permission",
        op_kwargs={
            "StackId": stack_id,
            "IamUserArn": iam_user_arn,
            "AllowSsh": allow_ssh,
            "AllowSudo": allow_sudo,
            "Level": level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, load_balancer_name: str, instances: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the state of the specified instances with respect to the specified load balancer. If no instances are specified, the call describes the state of all instances that are currently registered with the load balancer. If instances are specified, their state is returned even if they are no longer registered with the load balancer. The state of terminated instances is not returned.

    Args:
        load_balancer_name(str): The name of the load balancer.
        instances(List, optional): The IDs of the instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.instance.health.describe(ctx, load_balancer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.instance.health.describe load_balancer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="describe_instance_health",
        op_kwargs={"LoadBalancerName": load_balancer_name, "Instances": instances},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, messages: List) -> Dict:
    r"""
    **Autogenerated function**

    Sends a set of messages to the AWS IoT Events system. Each message payload is transformed into the input you specify ("inputName") and ingested into any detectors that monitor that input. If multiple messages are sent, the order in which the messages are processed isn't guaranteed. To guarantee ordering, you must send messages one at a time and wait for a successful response.

    Args:
        messages(List): The list of messages to send. Each message has the following format: '{ "messageId": "string", "inputName": "string", "payload": "string"}' .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent_data.put_message.batch(ctx, messages=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent_data.put_message.batch messages=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents-data",
        operation="batch_put_message",
        op_kwargs={"messages": messages},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, bucket: str, dry_run: bool = None, prefix: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a data feed for Spot Instances, enabling you to view Spot Instance usage logs. You can create one data feed per Amazon Web Services account. For more information, see Spot Instance data feed in the Amazon EC2 User Guide for Linux Instances.

    Args:
        bucket(str): The name of the Amazon S3 bucket in which to store the Spot Instance data feed. For more information about bucket names, see Rules for bucket naming in the Amazon S3 Developer Guide.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        prefix(str, optional): The prefix for the data feed file names. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.datafeed_subscription.create(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.datafeed_subscription.create bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_spot_datafeed_subscription",
        op_kwargs={"Bucket": bucket, "DryRun": dry_run, "Prefix": prefix},
    )


async def delete(hub, ctx, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the data feed for Spot Instances.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.datafeed_subscription.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.datafeed_subscription.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_spot_datafeed_subscription",
        op_kwargs={"DryRun": dry_run},
    )


async def describe(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the data feed for Spot Instances. For more information, see Spot Instance data feed in the Amazon EC2 User Guide for Linux Instances.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.spot.datafeed_subscription.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.spot.datafeed_subscription.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_spot_datafeed_subscription",
        op_kwargs={"DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disconnect(hub, ctx, source_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disconnects specific Source Servers from Application Migration Service. Data replication is stopped immediately. All AWS resources created by Application Migration Service for enabling the replication of these source servers will be terminated / deleted within 90 minutes. Launched Test or Cutover instances will NOT be terminated. If the agent on the source server has not been prevented from communciating with the Application Migration Service service, then it will receive a command to uninstall itself (within approximately 10 minutes). The following properties of the SourceServer will be changed immediately: dataReplicationInfo.dataReplicationState will be set to DISCONNECTED; The totalStorageBytes property for each of dataReplicationInfo.replicatedDisks will be set to zero; dataReplicationInfo.lagDuration and dataReplicationInfo.lagDurationwill be nullified.

    Args:
        source_server_id(str): Request to disconnect Source Server from service by Server ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.from_service.disconnect(ctx, source_server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.from_service.disconnect source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="disconnect_from_service",
        op_kwargs={"sourceServerID": source_server_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def describe(hub, ctx, user_pool_id: str, client_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the risk configuration.

    Args:
        user_pool_id(str): The user pool ID.
        client_id(str, optional): The app client ID. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.risk_configuration.describe(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.risk_configuration.describe user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="describe_risk_configuration",
        op_kwargs={"UserPoolId": user_pool_id, "ClientId": client_id},
    )


async def set_(
    hub,
    ctx,
    user_pool_id: str,
    client_id: str = None,
    compromised_credentials_risk_configuration: Dict = None,
    account_takeover_risk_configuration: Dict = None,
    risk_exception_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Configures actions on detected risks. To delete the risk configuration for UserPoolId or ClientId, pass null values for all four configuration types. To enable Amazon Cognito advanced security features, update the user pool to include the UserPoolAddOns keyAdvancedSecurityMode.

    Args:
        user_pool_id(str): The user pool ID. .
        client_id(str, optional): The app client ID. If ClientId is null, then the risk configuration is mapped to userPoolId. When the client ID is null, the same risk configuration is applied to all the clients in the userPool. Otherwise, ClientId is mapped to the client. When the client ID is not null, the user pool configuration is overridden and the risk configuration for the client is used instead. Defaults to None.
        compromised_credentials_risk_configuration(Dict, optional): The compromised credentials risk configuration. Defaults to None.
        account_takeover_risk_configuration(Dict, optional): The account takeover risk configuration. Defaults to None.
        risk_exception_configuration(Dict, optional): The configuration to override the risk decision. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.risk_configuration.set(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.risk_configuration.set user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="set_risk_configuration",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "ClientId": client_id,
            "CompromisedCredentialsRiskConfiguration": compromised_credentials_risk_configuration,
            "AccountTakeoverRiskConfiguration": account_takeover_risk_configuration,
            "RiskExceptionConfiguration": risk_exception_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def vote(
    hub, ctx, network_id: str, proposal_id: str, voter_member_id: str, vote: str
) -> Dict:
    r"""
    **Autogenerated function**

    Casts a vote for a specified ProposalId on behalf of a member. The member to vote as, specified by VoterMemberId, must be in the same AWS account as the principal that calls the action. Applies only to Hyperledger Fabric.

    Args:
        network_id(str):  The unique identifier of the network. .
        proposal_id(str):  The unique identifier of the proposal. .
        voter_member_id(str): The unique identifier of the member casting the vote. .
        vote(str):  The value of the vote. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.on_proposal.vote(
                ctx, network_id=value, proposal_id=value, voter_member_id=value, vote=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.on_proposal.vote network_id=value, proposal_id=value, voter_member_id=value, vote=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="vote_on_proposal",
        op_kwargs={
            "NetworkId": network_id,
            "ProposalId": proposal_id,
            "VoterMemberId": voter_member_id,
            "Vote": vote,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, account_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Describes all of the budget actions for an account.

    Args:
        account_id(str): The account ID of the user. It should be a 12-digit number.
        max_results(int, optional):  An integer that represents how many entries a paginated response contains. The maximum is 100. Defaults to None.
        next_token(str, optional):  A generic string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.budget.budget.action.for_.account.describe(
                ctx, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.budget.budget.action.for_.account.describe account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="budgets",
        operation="describe_budget_actions_for_account",
        op_kwargs={
            "AccountId": account_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    standards_subscription_arn: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of security standards controls. For each control, the results include information about whether it is currently enabled, the severity, and a link to remediation information.

    Args:
        standards_subscription_arn(str): The ARN of a resource that represents your subscription to a supported standard. To get the subscription ARNs of the standards you have enabled, use the GetEnabledStandards operation.
        next_token(str, optional): The token that is required for pagination. On your first call to the DescribeStandardsControls operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of security standard controls to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.standard.control.describe_all(
                ctx, standards_subscription_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.standard.control.describe_all standards_subscription_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="describe_standards_controls",
        op_kwargs={
            "StandardsSubscriptionArn": standards_subscription_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    standards_control_arn: str,
    control_status: str = None,
    disabled_reason: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to control whether an individual security standard control is enabled or disabled.

    Args:
        standards_control_arn(str): The ARN of the security standard control to enable or disable.
        control_status(str, optional): The updated status of the security standard control. Defaults to None.
        disabled_reason(str, optional): A description of the reason why you are disabling a security standard control. If you are disabling a control, then this is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.standard.control.update(
                ctx, standards_control_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.standard.control.update standards_control_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="update_standards_control",
        op_kwargs={
            "StandardsControlArn": standards_control_arn,
            "ControlStatus": control_status,
            "DisabledReason": disabled_reason,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    hyper_parameter_tuning_job_name: str,
    next_token: str = None,
    max_results: int = None,
    status_equals: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of TrainingJobSummary objects that describe the training jobs that a hyperparameter tuning job launched.

    Args:
        hyper_parameter_tuning_job_name(str): The name of the tuning job whose training jobs you want to list.
        next_token(str, optional): If the result of the previous ListTrainingJobsForHyperParameterTuningJob request was truncated, the response includes a NextToken. To retrieve the next set of training jobs, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of training jobs to return. The default value is 10. Defaults to None.
        status_equals(str, optional): A filter that returns only training jobs with the specified status. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is Name. If the value of this field is FinalObjectiveMetricValue, any training jobs that did not return an objective metric are not listed. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.training_jobs_for_hyper_parameter_tuning_job.list(
                ctx, hyper_parameter_tuning_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.training_jobs_for_hyper_parameter_tuning_job.list hyper_parameter_tuning_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_training_jobs_for_hyper_parameter_tuning_job",
        op_kwargs={
            "HyperParameterTuningJobName": hyper_parameter_tuning_job_name,
            "NextToken": next_token,
            "MaxResults": max_results,
            "StatusEquals": status_equals,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, instance_id: str = None, stack_id: str = None, raid_array_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describe an instance's RAID arrays.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        instance_id(str, optional): The instance ID. If you use this parameter, DescribeRaidArrays returns descriptions of the RAID arrays associated with the specified instance. . Defaults to None.
        stack_id(str, optional): The stack ID. Defaults to None.
        raid_array_ids(List, optional): An array of RAID array IDs. If you use this parameter, DescribeRaidArrays returns descriptions of the specified arrays. Otherwise, it returns a description of every array. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.raid_array.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.raid_array.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_raid_arrays",
        op_kwargs={
            "InstanceId": instance_id,
            "StackId": stack_id,
            "RaidArrayIds": raid_array_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def transfer(hub, ctx, domain_name: str, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Transfers a domain from the current AWS account to another AWS account. Note the following:   The AWS account that you're transferring the domain to must accept the transfer. If the other account doesn't accept the transfer within 3 days, we cancel the transfer. See AcceptDomainTransferFromAnotherAwsAccount.    You can cancel the transfer before the other account accepts it. See CancelDomainTransferToAnotherAwsAccount.    The other account can reject the transfer. See RejectDomainTransferFromAnotherAwsAccount.     When you transfer a domain from one AWS account to another, Route 53 doesn't transfer the hosted zone that is associated with the domain. DNS resolution isn't affected if the domain and the hosted zone are owned by separate accounts, so transferring the hosted zone is optional. For information about transferring the hosted zone to another AWS account, see Migrating a Hosted Zone to a Different AWS Account in the Amazon Route 53 Developer Guide.  Use either ListOperations or GetOperationDetail to determine whether the operation succeeded. GetOperationDetail provides additional information, for example, Domain Transfer from Aws Account 111122223333 has been cancelled.

    Args:
        domain_name(str): The name of the domain that you want to transfer from the current AWS account to another account.
        account_id(str): The account ID of the AWS account that you want to transfer the domain to, for example, 111122223333.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.to_another_aws_account.transfer(
                ctx, domain_name=value, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.to_another_aws_account.transfer domain_name=value, account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="transfer_domain_to_another_aws_account",
        op_kwargs={"DomainName": domain_name, "AccountId": account_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    user_arn: str,
    display_name: str,
    email_address: str,
    ssh_public_key: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a profile for a user that includes user preferences, such as the display name and email address assocciated with the user, in AWS CodeStar. The user profile is not project-specific. Information in the user profile is displayed wherever the user's information appears to other users in AWS CodeStar.

    Args:
        user_arn(str): The Amazon Resource Name (ARN) of the user in IAM.
        display_name(str): The name that will be displayed as the friendly name for the user in AWS CodeStar. .
        email_address(str): The email address that will be displayed as part of the user's profile in AWS CodeStar.
        ssh_public_key(str, optional): The SSH public key associated with the user in AWS CodeStar. If a project owner allows the user remote access to project resources, this public key will be used along with the user's private key for SSH access. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.user_profile.create(
                ctx, user_arn=value, display_name=value, email_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.user_profile.create user_arn=value, display_name=value, email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="create_user_profile",
        op_kwargs={
            "userArn": user_arn,
            "displayName": display_name,
            "emailAddress": email_address,
            "sshPublicKey": ssh_public_key,
        },
    )


async def delete(hub, ctx, user_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a user profile in AWS CodeStar, including all personal preference data associated with that profile, such as display name and email address. It does not delete the history of that user, for example the history of commits made by that user.

    Args:
        user_arn(str): The Amazon Resource Name (ARN) of the user to delete from AWS CodeStar.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.user_profile.delete(ctx, user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.user_profile.delete user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="delete_user_profile",
        op_kwargs={"userArn": user_arn},
    )


async def describe(hub, ctx, user_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a user in AWS CodeStar and the user attributes across all projects.

    Args:
        user_arn(str): The Amazon Resource Name (ARN) of the user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.user_profile.describe(ctx, user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.user_profile.describe user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="describe_user_profile",
        op_kwargs={"userArn": user_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the user profiles configured for your AWS account in AWS CodeStar.

    Args:
        next_token(str, optional): The continuation token for the next set of results, if the results cannot be returned in one response. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.user_profile.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.user_profile.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="list_user_profiles",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    user_arn: str,
    display_name: str = None,
    email_address: str = None,
    ssh_public_key: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a user's profile in AWS CodeStar. The user profile is not project-specific. Information in the user profile is displayed wherever the user's information appears to other users in AWS CodeStar.

    Args:
        user_arn(str): The name that will be displayed as the friendly name for the user in AWS CodeStar.
        display_name(str, optional): The name that is displayed as the friendly name for the user in AWS CodeStar. Defaults to None.
        email_address(str, optional): The email address that is displayed as part of the user's profile in AWS CodeStar. Defaults to None.
        ssh_public_key(str, optional): The SSH public key associated with the user in AWS CodeStar. If a project owner allows the user remote access to project resources, this public key will be used along with the user's private key for SSH access. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.user_profile.update(ctx, user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.user_profile.update user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="update_user_profile",
        op_kwargs={
            "userArn": user_arn,
            "displayName": display_name,
            "emailAddress": email_address,
            "sshPublicKey": ssh_public_key,
        },
    )
